#include "loadexampledialog.h"

#include <QDialogButtonBox>
#include <QVBoxLayout>

/*!
 * \class LoadExampleDialog
 * \brief The LoadExampleDialog class displays the available example rope rosettes.
 *
 * It inherits QDialog. Examples are loaded through ReadExampleFile.
 * When an example is selected, the model for plot and paramters is changed to model of the
 * selected example rosette.
 */

/*!
 * \brief Constructs LoadExampleDialog.
 *
 * Sets up the LoadExampleDialog GUI and connects signals for user interaction.
 * \param names A list of named example rosettes.
 * \param parent The parent of LoadExampleDialog.
 */
LoadExampleDialog::LoadExampleDialog(QStringList names, QWidget *parent) : QDialog(parent)
{

    nameList = new QListWidget(this);
    nameList->addItems(names);

    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok
                                       | QDialogButtonBox::Cancel, this);

    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
    connect(nameList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(accept()));

    QVBoxLayout *layout = new QVBoxLayout();
    layout->addWidget(nameList);
    layout->addWidget(buttonBox);
    this->setLayout(layout);

}

/*!
 * \brief Detroys LoadExampleDialog.
 */
LoadExampleDialog::~LoadExampleDialog()
{

}

/*!
 * \fn LoadExampleDialog::selectedExample(int selectedRow)
 *
 * This signal is emitted when an example has been selected.
 * \param selectedRow The index of the selected row.
 */

/*!
 * \brief Triggered when an example is selected and LoadExampleDialog closed.
 *
 * Gets the \a index of the selected example rosette. Emits signal \a selectedExample(index).
 */
void LoadExampleDialog::accept()
{
    QModelIndex index = nameList->currentIndex();
    emit selectedExample(index.row());
    QDialog::accept();
}
