#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "drawwidget.h"
#include "helpdialogwidget.h"
#include "loadexampledialog.h"
#include "processwidget.h"
#include "readexamplefile.h"
#include "variableadjustwidget.h"

#include <QStandardItemModel>

class DrawWidget;
class LoadExampleDialog;
class ProcessWidget;
class ReadExampleFile;
class VariableAdjustWidget;
class QStandardItemModel;

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

private slots:
    void helpDialog();
    void loadDialog();

    void setModels(int index);
    void tracedModel(QStandardItemModel *model);

    void setStatusBar(QString text);
    void clearStatusBar();

    void openImage();
    void saveImage();

    void updateActionBar(int index);

private:
    DrawWidget *drawGraphWidget; /*!< The widget for synthesis mode.*/
    HelpDialogWidget *helpWidget; /*!< Dialog for user guide and about.*/
    LoadExampleDialog *loadExampleDialog; /*!< Dialog for selecting which example rosette to load.*/
    ProcessWidget *processImage; /*!< The widget for process mode.*/
    ReadExampleFile *exampleValues; /*!< Class for reading example file.*/
    VariableAdjustWidget *variableAdjustmentWidget; /*!< Widget for editing of rosette parameters.*/

    void setupToolbar();
    void setShortcuts();
};

#endif // MAINWINDOW_H
